﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls.DragDrop;
using Telerik.Windows;
using System.Collections;
using System.Collections.ObjectModel;
using Telerik.Windows.Controls;

namespace TabControlToTileView
{
	public partial class MainPage : UserControl
	{
		public MainPage()
		{
			InitializeComponent();

			this.MyTabControl.ItemsSource = GenerateTabs();
			this.MyTileView.ItemsSource = GenerateTiles();

			MyTabControl.AddHandler(RadDragAndDropManager.DragQueryEvent, new EventHandler<DragDropQueryEventArgs>(OnDragQuery));
			MyTabControl.AddHandler(RadDragAndDropManager.DragInfoEvent, new EventHandler<DragDropEventArgs>(OnDragInfo));

			MyTileView.AddHandler(RadDragAndDropManager.DropQueryEvent, new EventHandler<DragDropQueryEventArgs>(OnDropQuery));
			MyTileView.AddHandler(RadDragAndDropManager.DropInfoEvent, new EventHandler<DragDropEventArgs>(OnDropInfo));
		}
		#region Generate data
		public ObservableCollection<DataItem> GenerateTabs()
		{
			ObservableCollection<DataItem> result = new ObservableCollection<DataItem>();
			for (int i = 0; i < 10; i++)
			{
				DataItem tab = new DataItem();
				tab.Header = String.Format("Header {0}", i);
				tab.Details = String.Format("Details {0}", i);
				result.Add(tab);
			}
			return result;
		}


		public ObservableCollection<DataItem> GenerateTiles()
		{
			ObservableCollection<DataItem> result = new ObservableCollection<DataItem>();
			for (int i = 0; i < 5; i++)
			{
				DataItem tile = new DataItem();
				tile.Header = String.Format("Header {0}", i);
				tile.Details = String.Format("Details {0}", i);
				result.Add(tile);
			}
			return result;
		}
		#endregion

		#region DragDrop event handlers

		// OnDragQuery event handler
		private void OnDragQuery(object sender, DragDropQueryEventArgs e)
		{
			if (e.Options.Status == DragStatus.DragQuery)
			{
				var draggedItem = e.Options.Source;
				e.QueryResult = true;
				e.Handled = true;
				// Create Drag and Arrow Cue
				ContentControl dragCue = new ContentControl();
				dragCue.Content = draggedItem.DataContext;
				dragCue.ContentTemplate = this.Resources["DragCueTemplate"] as DataTemplate;
				e.Options.DragCue = dragCue;
				e.Options.ArrowCue = RadDragAndDropManager.GenerateArrowCue();
				// Set the payload (this is the item that is currently dragged)
				e.Options.Payload = draggedItem.DataContext;
			}
			if (e.Options.Status == DragStatus.DropSourceQuery)
			{
				e.QueryResult = true;
				e.Handled = true;
			}
		}

		// OnDropQuery event handler
		private void OnDropQuery(object sender, DragDropQueryEventArgs e)
		{
			e.Handled = true;
			e.QueryResult = true;
		}

		// OnDropInfo event handler
		private void OnDropInfo(object sender, DragDropEventArgs e)
		{
			var destination = e.Options.Destination as Telerik.Windows.Controls.ItemsControl;
			if (e.Options.Status == DragStatus.DropComplete &&
				 destination != null)
			{
				(destination.ItemsSource as IList).Add(e.Options.Payload);
			}
		}

		// OnDragInfo event handler
		private void OnDragInfo(object sender, DragDropEventArgs e)
		{
			// remove the dragged item from the TabControl.
			if (e.Options.Status == DragStatus.DragComplete)
			{
				RadTabControl tabControl = sender as RadTabControl;
				(tabControl.ItemsSource as IList).Remove(e.Options.Payload);
			}

		}

		#endregion
	}
	public class DataItem
	{
		public string Header { get; set; }
		public string Details { get; set; }
	}
}
